# coding: utf-8

"""
    API BIS-сервиса \"Telegram\"

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.messages_api import MessagesApi


class TestMessagesApi(unittest.TestCase):
    """ MessagesApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.messages_api.MessagesApi()

    def tearDown(self):
        pass

    def test_create(self):
        """
        Test case for create

        
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    API BIS-сервиса \"Telegram\"

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .data import Data



# coding: utf-8

"""
    API BIS-сервиса \"Telegram\"

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.data import Data

# import apis into sdk package
from .apis.messages_api import MessagesApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
    API BIS-сервиса \"Telegram\"

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import sys
from setuptools import setup, find_packages

NAME = "bis-telegram-client-py"
VERSION = "0.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="API BIS-сервиса \&quot;Telegram\&quot;",
    author_email="",
    url="",
    keywords=["Swagger", "API BIS-сервиса \&quot;Telegram\&quot;"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
    """
)
